from threading import Thread, Timer
from datetime import date

from .utils import num_to_pixels
from ..tempo import convert_color


class InfoPanel:
    def __init__(self, sense, tempo_api, rotation=0):
        self.sense = sense
        self.stick = self.sense.stick
        self.rotation = rotation
        self.sense.set_rotation(self.rotation)

        self.tempo_api = tempo_api

        self.start_stick_info()
        self.clear_timer = Timer(5, self.sense.clear)

    def start_stick_info(self):
        self.thread = Thread(target=self.stick_info)
        self.thread.start()

    def start_clear_timer(self):
        self.clear_timer.cancel()
        self.clear_timer = Timer(5, self.sense.clear)
        self.clear_timer.start()

    def stick_info(self):
        event = self.stick.wait_for_event(emptybuffer=True)
        self.start_stick_info()

        match event.direction:
            case "up":
                self.show_trash()
            case "right":
                self.show_temp()
            case "left":
                self.show_humidity()
            case "down":
                self.show_tempo()
            case "middle":
                self.sense.clear()

        self.start_clear_timer()

    def show_trash(self):
        today = date.today().isocalendar()
        if (today.week % 2) ^ (today.weekday >= 4):
            self.sense.set_pixels(64 * [[255, 255, 0]])
        else:
            grid_line = 4 * [[0, 127, 0], [0, 15, 0]]
            self.sense.set_pixels(4 * (grid_line + grid_line[::-1]))

    def show_temp(self):
        self.sense.set_pixels(
            num_to_pixels(self.sense.temperature, color=[255, 0, 255])
        )

    def show_humidity(self):
        self.sense.set_pixels(num_to_pixels(self.sense.humidity, color=[0, 255, 255]))

    def show_tempo(self):
        tempo_colors = [convert_color(c) for c in self.tempo_api.tempo]
        self.sense.set_pixels([tempo_colors[1]] * 48 + [tempo_colors[0]] * 16)
