from datetime import date, datetime, timedelta, timezone
from threading import Timer
import psycopg
from psycopg_pool import ConnectionPool


class SenseLogger:
    def __init__(self, sense, conninfo):
        self.sense = sense
        self.database_pool = ConnectionPool(conninfo)

        self.timer = Timer(0, self.log)
        self.timer.start()

    def log(self):
        self.timer = Timer(30, self.log)
        self.timer.start()

        dt = datetime.now()

        temp = self.sense.temperature
        pres = self.sense.pressure
        humi = self.sense.humidity

        print(dt)
        INS = "INSERT INTO sensor_data (time, sensor, value) VALUES (%s, %s, %s);"

        conn = self.database_pool.getconn()
        try:
            with conn.cursor() as cursor:
                cursor.execute(INS, (dt, "temp", temp))
                cursor.execute(INS, (dt, "pres", pres))
                cursor.execute(INS, (dt, "humi", humi))

                conn.commit()
        except:
            conn.rollback()
            raise
        finally:
            self.database_pool.putconn(conn)
