from datetime import date, datetime, timedelta, timezone
from threading import Timer
from urllib import request, parse
import json


class TempoAPI:
    def __init__(self, api_key):
        self.rte_api_key = api_key
        self.update_rte_access_token()

    def update_rte_access_token(self):
        with request.urlopen(
            request.Request(
                "https://digital.iservices.rte-france.com/token/oauth/",
                headers={
                    "Authorization": f"Basic {self.rte_api_key}",
                    "Content-Type": "application/x-www-form-urlencoded",
                },
                method="POST",
            )
        ) as res:
            data = json.load(res)

        self.rte_access_token = data.get("access_token")
        self.renewal_timer = Timer(data.get("expires_in"), self.update_rte_access_token)
        self.renewal_timer.start()

    @property
    def tempo(self):
        today = datetime.combine(date.today(), datetime.min.time()).astimezone()
        url = parse.urljoin(
            "https://digital.iservices.rte-france.com/open_api/tempo_like_supply_contract/v1/tempo_like_calendars",
            "?"
            + parse.urlencode(
                {
                    "start_date": today.isoformat(),
                    "end_date": (today + timedelta(days=2)).isoformat(),
                },
                safe=":",
            ),
        )
        with request.urlopen(
            request.Request(
                url,
                headers={
                    "Authorization": f"Bearer {self.rte_access_token}",
                    "Accept": "application/json",
                },
            )
        ) as res:
            api_data = json.load(res)

        return [
            val.get("value")
            for val in api_data.get("tempo_like_calendars").get("values")
        ]


def convert_color(color):
    match color:
        case "BLUE":
            return [0, 0, 255]
        case "WHITE":
            return [255, 255, 255]
        case "RED":
            return [255, 0, 0]
        case _:
            return [255, 255, 0]
